arrow-integration-test 56.2.1

Support for the Apache Arrow JSON test data format
docs.rs failed to build arrow-integration-test-56.2.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: arrow-integration-test-58.3.0

Support for the Apache Arrow JSON test data format

These utilities define structs that read the integration JSON format for integration testing purposes.

This is not a canonical format, but provides a human-readable way of verifying language implementations